#!/bin/sh
# script to generate tarball from upstream git
which git > /dev/null 2>&1
if [ $? -gt 0 ]; then
  echo "No git found. Install git-core"
  exit 1
fi
which lua > /dev/null 2>&1
if [ $? -gt 0 ]; then
  echo "No lua found. Install lua"
  exit 1
fi
set -e
giturl='https://github.com/LuaJIT/LuaJIT.git'
cwd=$(pwd)
tmpdir=$(mktemp -d)
if [ -n "$1" ]
then
    version="$1"
else
    version='v2.1'
fi
cd $tmpdir
git clone "$giturl"
cd LuaJIT
git checkout $version
git config tar.tar.xz.command 'xz -c'
make luajit.h -C src HOST_LUA=lua
if [ -e src/luajit.h ]; then
  tarball=$(grep -e LUAJIT_VERSION\\s src/luajit.h |cut -d'"' -f2-2|tr ' ' '-')
  git archive --format=tar.xz -o ${tarball}.tar.xz --prefix=${tarball}/ $version
else
  echo "Something went wrong!"
  cd "$cwd"
  rm -Rf "$tmpdir"
  exit 1
fi

for file in *.tar.xz
do
    if [ -e "$cwd/$file" ]
    then
        echo "File already exists, backing up the old one as $cwd/$file.bak" >&2
        mv -f "$cwd/$file" "$cwd/$file.bak"
    fi
    mv "$file" "$cwd/$file"
    echo "----> $file"
done
cd "$cwd"
rm -Rf "$tmpdir"
